==> libreoffice-still-sdk-25.2.6-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/namespacecom_1_1sun_1_1star.js <==
var namespacecom_1_1sun_1_1star =
[
    [ "accessibility", "namespacecom_1_1sun_1_1star_1_1accessibility.html", "namespacecom_1_1sun_1_1star_1_1accessibility" ],
    [ "animations", "namespacecom_1_1sun_1_1star_1_1animations.html", "namespacecom_1_1sun_1_1star_1_1animations" ],
    [ "auth", "namespacecom_1_1sun_1_1star_1_1auth.html", "namespacecom_1_1sun_1_1star_1_1auth" ],
    [ "awt", "namespacecom_1_1sun_1_1star_1_1awt.html", "namespacecom_1_1sun_1_1star_1_1awt" ],
    [ "beans", "namespacecom_1_1sun_1_1star_1_1beans.html", "namespacecom_1_1sun_1_1star_1_1beans" ],
    [ "bridge", "namespacecom_1_1sun_1_1star_1_1bridge.html", "namespacecom_1_1sun_1_1star_1_1bridge" ],
    [ "chart", "namespacecom_1_1sun_1_1star_1_1chart.html", "namespacecom_1_1sun_1_1star_1_1chart" ],
    [ "chart2", "namespacecom_1_1sun_1_1star_1_1chart2.html", "namespacecom_1_1sun_1_1star_1_1chart2" ],
    [ "configuration", "namespacecom_1_1sun_1_1star_1_1configuration.html", "namespacecom_1_1sun_1_1star_1_1configuration" ],
    [ "connection", "namespacecom_1_1sun_1_1star_1_1connection.html", "namespacecom_1_1sun_1_1star_1_1connection" ],
    [ "container", "namespacecom_1_1sun_1_1star_1_1container.html", "namespacecom_1_1sun_1_1star_1_1container" ],
    [ "cui", "namespacecom_1_1sun_1_1star_1_1cui.html", "namespacecom_1_1sun_1_1star_1_1cui" ],
    [ "datatransfer", "namespacecom_1_1sun_1_1star_1_1datatransfer.html", "namespacecom_1_1sun_1_1star_1_1datatransfer" ],
    [ "deployment", "namespacecom_1_1sun_1_1star_1_1deployment.html", "namespacecom_1_1sun_1_1star_1_1deployment" ],
    [ "document", "namespacecom_1_1sun_1_1star_1_1document.html", "namespacecom_1_1sun_1_1star_1_1document" ],
    [ "drawing", "namespacecom_1_1sun_1_1star_1_1drawing.html", "namespacecom_1_1sun_1_1star_1_1drawing" ],
    [ "embed", "namespacecom_1_1sun_1_1star_1_1embed.html", "namespacecom_1_1sun_1_1star_1_1embed" ],
    [ "form", "namespacecom_1_1sun_1_1star_1_1form.html", "namespacecom_1_1sun_1_1star_1_1form" ],
    [ "formula", "namespacecom_1_1sun_1_1star_1_1formula.html", "namespacecom_1_1sun_1_1star_1_1formula" ],
    [ "frame", "namespacecom_1_1sun_1_1star_1_1frame.html", "namespacecom_1_1sun_1_1star_1_1frame" ],
    [ "gallery", "namespacecom_1_1sun_1_1star_1_1gallery.html", "namespacecom_1_1sun_1_1star_1_1gallery" ],
    [ "geometry", "namespacecom_1_1sun_1_1star_1_1geometry.html", "namespacecom_1_1sun_1_1star_1_1geometry" ],
    [ "graphic", "namespacecom_1_1sun_1_1star_1_1graphic.html", "namespacecom_1_1sun_1_1star_1_1graphic" ],
    [ "i18n", "namespacecom_1_1sun_1_1star_1_1i18n.html", "namespacecom_1_1sun_1_1star_1_1i18n" ],
    [ "image", "namespacecom_1_1sun_1_1star_1_1image.html", "namespacecom_1_1sun_1_1star_1_1image" ],
    [ "inspection", "namespacecom_1_1sun_1_1star_1_1inspection.html", "namespacecom_1_1sun_1_1star_1_1inspection" ],
    [ "io", "namespacecom_1_1sun_1_1star_1_1io.html", "namespacecom_1_1sun_1_1star_1_1io" ],
    [ "java", "namespacecom_1_1sun_1_1star_1_1java.html", "namespacecom_1_1sun_1_1star_1_1java" ],
    [ "lang", "namespacecom_1_1sun_1_1star_1_1lang.html", "namespacecom_1_1sun_1_1star_1_1lang" ],
    [ "ldap", "namespacecom_1_1sun_1_1star_1_1ldap.html", "namespacecom_1_1sun_1_1star_1_1ldap" ],
    [ "linguistic2", "namespacecom_1_1sun_1_1star_1_1linguistic2.html", "namespacecom_1_1sun_1_1star_1_1linguistic2" ],
    [ "loader", "namespacecom_1_1sun_1_1star_1_1loader.html", "namespacecom_1_1sun_1_1star_1_1loader" ],
    [ "logging", "namespacecom_1_1sun_1_1star_1_1logging.html", "namespacecom_1_1sun_1_1star_1_1logging" ],
    [ "mail", "namespacecom_1_1sun_1_1star_1_1mail.html", "namespacecom_1_1sun_1_1star_1_1mail" ],
    [ "media", "namespacecom_1_1sun_1_1star_1_1media.html", "namespacecom_1_1sun_1_1star_1_1media" ],
    [ "mozilla", "namespacecom_1_1sun_1_1star_1_1mozilla.html", "namespacecom_1_1sun_1_1star_1_1mozilla" ],
    [ "office", "namespacecom_1_1sun_1_1star_1_1office.html", "namespacecom_1_1sun_1_1star_1_1office" ],
    [ "packages", "namespacecom_1_1sun_1_1star_1_1packages.html", "namespacecom_1_1sun_1_1star_1_1packages" ],
    [ "plugin", "namespacecom_1_1sun_1_1star_1_1plugin.html", null ],
    [ "presentation", "namespacecom_1_1sun_1_1star_1_1presentation.html", "namespacecom_1_1sun_1_1star_1_1presentation" ],
    [ "qa", "namespacecom_1_1sun_1_1star_1_1qa.html", "namespacecom_1_1sun_1_1star_1_1qa" ],
    [ "rdf", "namespacecom_1_1sun_1_1star_1_1rdf.html", "namespacecom_1_1sun_1_1star_1_1rdf" ],
    [ "reflection", "namespacecom_1_1sun_1_1star_1_1reflection.html", "namespacecom_1_1sun_1_1star_1_1reflection" ],
    [ "registry", "namespacecom_1_1sun_1_1star_1_1registry.html", "namespacecom_1_1sun_1_1star_1_1registry" ],
    [ "rendering", "namespacecom_1_1sun_1_1star_1_1rendering.html", "namespacecom_1_1sun_1_1star_1_1rendering" ],
    [ "report", "namespacecom_1_1sun_1_1star_1_1report.html", "namespacecom_1_1sun_1_1star_1_1report" ],
    [ "resource", "namespacecom_1_1sun_1_1star_1_1resource.html", "namespacecom_1_1sun_1_1star_1_1resource" ],
    [ "scanner", "namespacecom_1_1sun_1_1star_1_1scanner.html", "namespacecom_1_1sun_1_1star_1_1scanner" ],
    [ "script", "namespacecom_1_1sun_1_1star_1_1script.html", "namespacecom_1_1sun_1_1star_1_1script" ],
    [ "sdb", "namespacecom_1_1sun_1_1star_1_1sdb.html", "namespacecom_1_1sun_1_1star_1_1sdb" ],
    [ "sdbc", "namespacecom_1_1sun_1_1star_1_1sdbc.html", "namespacecom_1_1sun_1_1star_1_1sdbc" ],
    [ "sdbcx", "namespacecom_1_1sun_1_1star_1_1sdbcx.html", "namespacecom_1_1sun_1_1star_1_1sdbcx" ],
    [ "security", "namespacecom_1_1sun_1_1star_1_1security.html", "namespacecom_1_1sun_1_1star_1_1security" ],
    [ "setup", "namespacecom_1_1sun_1_1star_1_1setup.html", "namespacecom_1_1sun_1_1star_1_1setup" ],
    [ "sheet", "namespacecom_1_1sun_1_1star_1_1sheet.html", "namespacecom_1_1sun_1_1star_1_1sheet" ],
    [ "smarttags", "namespacecom_1_1sun_1_1star_1_1smarttags.html", "namespacecom_1_1sun_1_1star_1_1smarttags" ],
    [ "style", "namespacecom_1_1sun_1_1star_1_1style.html", "namespacecom_1_1sun_1_1star_1_1style" ],
    [ "svg", "namespacecom_1_1sun_1_1star_1_1svg.html", "namespacecom_1_1sun_1_1star_1_1svg" ],
    [ "system", "namespacecom_1_1sun_1_1star_1_1system.html", "namespacecom_1_1sun_1_1star_1_1system" ],
    [ "table", "namespacecom_1_1sun_1_1star_1_1table.html", "namespacecom_1_1sun_1_1star_1_1table" ],
    [ "task", "namespacecom_1_1sun_1_1star_1_1task.html", "namespacecom_1_1sun_1_1star_1_1task" ],
    [ "text", "namespacecom_1_1sun_1_1star_1_1text.html", "namespacecom_1_1sun_1_1star_1_1text" ],
    [ "tiledrendering", "namespacecom_1_1sun_1_1star_1_1tiledrendering.html", "namespacecom_1_1sun_1_1star_1_1tiledrendering" ],
    [ "ucb", "namespacecom_1_1sun_1_1star_1_1ucb.html", "namespacecom_1_1sun_1_1star_1_1ucb" ],
    [ "ui", "namespacecom_1_1sun_1_1star_1_1ui.html", "namespacecom_1_1sun_1_1star_1_1ui" ],
    [ "uno", "namespacecom_1_1sun_1_1star_1_1uno.html", "namespacecom_1_1sun_1_1star_1_1uno" ],
    [ "uri", "namespacecom_1_1sun_1_1star_1_1uri.html", "namespacecom_1_1sun_1_1star_1_1uri" ],
    [ "util", "namespacecom_1_1sun_1_1star_1_1util.html", "namespacecom_1_1sun_1_1star_1_1util" ],
    [ "view", "namespacecom_1_1sun_1_1star_1_1view.html", "namespacecom_1_1sun_1_1star_1_1view" ],
    [ "xforms", "namespacecom_1_1sun_1_1star_1_1xforms.html", "namespacecom_1_1sun_1_1star_1_1xforms" ],
    [ "xml", "namespacecom_1_1sun_1_1star_1_1xml.html", "namespacecom_1_1sun_1_1star_1_1xml" ],
    [ "xsd", "namespacecom_1_1sun_1_1star_1_1xsd.html", "namespacecom_1_1sun_1_1star_1_1xsd" ]
];

==> libreoffice-still-sdk-25.2.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/namespacecom_1_1sun_1_1star.js <==
var namespacecom_1_1sun_1_1star =
[
    [ "beans", "namespacecom_1_1sun_1_1star_1_1beans.html", "namespacecom_1_1sun_1_1star_1_1beans" ],
    [ "bridge", "namespacecom_1_1sun_1_1star_1_1bridge.html", "namespacecom_1_1sun_1_1star_1_1bridge" ],
    [ "connection", "namespacecom_1_1sun_1_1star_1_1connection.html", "namespacecom_1_1sun_1_1star_1_1connection" ],
    [ "container", "namespacecom_1_1sun_1_1star_1_1container.html", "namespacecom_1_1sun_1_1star_1_1container" ],
    [ "io", "namespacecom_1_1sun_1_1star_1_1io.html", "namespacecom_1_1sun_1_1star_1_1io" ],
    [ "java", "namespacecom_1_1sun_1_1star_1_1java.html", "namespacecom_1_1sun_1_1star_1_1java" ],
    [ "lang", "namespacecom_1_1sun_1_1star_1_1lang.html", "namespacecom_1_1sun_1_1star_1_1lang" ],
    [ "loader", "namespacecom_1_1sun_1_1star_1_1loader.html", "namespacecom_1_1sun_1_1star_1_1loader" ],
    [ "reflection", "namespacecom_1_1sun_1_1star_1_1reflection.html", "namespacecom_1_1sun_1_1star_1_1reflection" ],
    [ "registry", "namespacecom_1_1sun_1_1star_1_1registry.html", "namespacecom_1_1sun_1_1star_1_1registry" ],
    [ "script", "namespacecom_1_1sun_1_1star_1_1script.html", "namespacecom_1_1sun_1_1star_1_1script" ],
    [ "security", "namespacecom_1_1sun_1_1star_1_1security.html", "namespacecom_1_1sun_1_1star_1_1security" ],
    [ "uno", "namespacecom_1_1sun_1_1star_1_1uno.html", "namespacecom_1_1sun_1_1star_1_1uno" ],
    [ "uri", "namespacecom_1_1sun_1_1star_1_1uri.html", "namespacecom_1_1sun_1_1star_1_1uri" ],
    [ "task", "namespacecom_1_1sun_1_1star_1_1task.html", "namespacecom_1_1sun_1_1star_1_1task" ],
    [ "util", "namespacecom_1_1sun_1_1star_1_1util.html", "namespacecom_1_1sun_1_1star_1_1util" ],
    [ "accessibility", "namespacecom_1_1sun_1_1star_1_1accessibility.html", "namespacecom_1_1sun_1_1star_1_1accessibility" ],
    [ "animations", "namespacecom_1_1sun_1_1star_1_1animations.html", "namespacecom_1_1sun_1_1star_1_1animations" ],
    [ "auth", "namespacecom_1_1sun_1_1star_1_1auth.html", "namespacecom_1_1sun_1_1star_1_1auth" ],
    [ "awt", "namespacecom_1_1sun_1_1star_1_1awt.html", "namespacecom_1_1sun_1_1star_1_1awt" ],
    [ "datatransfer", "namespacecom_1_1sun_1_1star_1_1datatransfer.html", "namespacecom_1_1sun_1_1star_1_1datatransfer" ],
    [ "chart", "namespacecom_1_1sun_1_1star_1_1chart.html", "namespacecom_1_1sun_1_1star_1_1chart" ],
    [ "chart2", "namespacecom_1_1sun_1_1star_1_1chart2.html", "namespacecom_1_1sun_1_1star_1_1chart2" ],
    [ "configuration", "namespacecom_1_1sun_1_1star_1_1configuration.html", "namespacecom_1_1sun_1_1star_1_1configuration" ],
    [ "cui", "namespacecom_1_1sun_1_1star_1_1cui.html", "namespacecom_1_1sun_1_1star_1_1cui" ],
    [ "xml", "namespacecom_1_1sun_1_1star_1_1xml.html", "namespacecom_1_1sun_1_1star_1_1xml" ],
    [ "deployment", "namespacecom_1_1sun_1_1star_1_1deployment.html", "namespacecom_1_1sun_1_1star_1_1deployment" ],
    [ "document", "namespacecom_1_1sun_1_1star_1_1document.html", "namespacecom_1_1sun_1_1star_1_1document" ],
    [ "drawing", "namespacecom_1_1sun_1_1star_1_1drawing.html", "namespacecom_1_1sun_1_1star_1_1drawing" ],
    [ "view", "namespacecom_1_1sun_1_1star_1_1view.html", "namespacecom_1_1sun_1_1star_1_1view" ],
    [ "embed", "namespacecom_1_1sun_1_1star_1_1embed.html", "namespacecom_1_1sun_1_1star_1_1embed" ],
    [ "form", "namespacecom_1_1sun_1_1star_1_1form.html", "namespacecom_1_1sun_1_1star_1_1form" ],
    [ "formula", "namespacecom_1_1sun_1_1star_1_1formula.html", "namespacecom_1_1sun_1_1star_1_1formula" ],
    [ "frame", "namespacecom_1_1sun_1_1star_1_1frame.html", "namespacecom_1_1sun_1_1star_1_1frame" ],
    [ "gallery", "namespacecom_1_1sun_1_1star_1_1gallery.html", "namespacecom_1_1sun_1_1star_1_1gallery" ],
    [ "geometry", "namespacecom_1_1sun_1_1star_1_1geometry.html", "namespacecom_1_1sun_1_1star_1_1geometry" ],
    [ "graphic", "namespacecom_1_1sun_1_1star_1_1graphic.html", "namespacecom_1_1sun_1_1star_1_1graphic" ],
    [ "i18n", "namespacecom_1_1sun_1_1star_1_1i18n.html", "namespacecom_1_1sun_1_1star_1_1i18n" ],
    [ "image", "namespacecom_1_1sun_1_1star_1_1image.html", "namespacecom_1_1sun_1_1star_1_1image" ],
    [ "inspection", "namespacecom_1_1sun_1_1star_1_1inspection.html", "namespacecom_1_1sun_1_1star_1_1inspection" ],
    [ "ldap", "namespacecom_1_1sun_1_1star_1_1ldap.html", "namespacecom_1_1sun_1_1star_1_1ldap" ],
    [ "linguistic2", "namespacecom_1_1sun_1_1star_1_1linguistic2.html", "namespacecom_1_1sun_1_1star_1_1linguistic2" ],
    [ "logging", "namespacecom_1_1sun_1_1star_1_1logging.html", "namespacecom_1_1sun_1_1star_1_1logging" ],
    [ "mail", "namespacecom_1_1sun_1_1star_1_1mail.html", "namespacecom_1_1sun_1_1star_1_1mail" ],
    [ "media", "namespacecom_1_1sun_1_1star_1_1media.html", "namespacecom_1_1sun_1_1star_1_1media" ],
    [ "mozilla", "namespacecom_1_1sun_1_1star_1_1mozilla.html", "namespacecom_1_1sun_1_1star_1_1mozilla" ],
    [ "office", "namespacecom_1_1sun_1_1star_1_1office.html", "namespacecom_1_1sun_1_1star_1_1office" ],
    [ "packages", "namespacecom_1_1sun_1_1star_1_1packages.html", "namespacecom_1_1sun_1_1star_1_1packages" ],
    [ "plugin", "namespacecom_1_1sun_1_1star_1_1plugin.html", null ],
    [ "presentation", "namespacecom_1_1sun_1_1star_1_1presentation.html", "namespacecom_1_1sun_1_1star_1_1presentation" ],
    [ "qa", "namespacecom_1_1sun_1_1star_1_1qa.html", "namespacecom_1_1sun_1_1star_1_1qa" ],
    [ "rdf", "namespacecom_1_1sun_1_1star_1_1rdf.html", "namespacecom_1_1sun_1_1star_1_1rdf" ],
    [ "rendering", "namespacecom_1_1sun_1_1star_1_1rendering.html", "namespacecom_1_1sun_1_1star_1_1rendering" ],
    [ "report", "namespacecom_1_1sun_1_1star_1_1report.html", "namespacecom_1_1sun_1_1star_1_1report" ],
    [ "resource", "namespacecom_1_1sun_1_1star_1_1resource.html", "namespacecom_1_1sun_1_1star_1_1resource" ],
    [ "scanner", "namespacecom_1_1sun_1_1star_1_1scanner.html", "namespacecom_1_1sun_1_1star_1_1scanner" ],
    [ "sdb", "namespacecom_1_1sun_1_1star_1_1sdb.html", "namespacecom_1_1sun_1_1star_1_1sdb" ],
    [ "sdbc", "namespacecom_1_1sun_1_1star_1_1sdbc.html", "namespacecom_1_1sun_1_1star_1_1sdbc" ],
    [ "sdbcx", "namespacecom_1_1sun_1_1star_1_1sdbcx.html", "namespacecom_1_1sun_1_1star_1_1sdbcx" ],
    [ "setup", "namespacecom_1_1sun_1_1star_1_1setup.html", "namespacecom_1_1sun_1_1star_1_1setup" ],
    [ "sheet", "namespacecom_1_1sun_1_1star_1_1sheet.html", "namespacecom_1_1sun_1_1star_1_1sheet" ],
    [ "smarttags", "namespacecom_1_1sun_1_1star_1_1smarttags.html", "namespacecom_1_1sun_1_1star_1_1smarttags" ],
    [ "style", "namespacecom_1_1sun_1_1star_1_1style.html", "namespacecom_1_1sun_1_1star_1_1style" ],
    [ "svg", "namespacecom_1_1sun_1_1star_1_1svg.html", "namespacecom_1_1sun_1_1star_1_1svg" ],
    [ "system", "namespacecom_1_1sun_1_1star_1_1system.html", "namespacecom_1_1sun_1_1star_1_1system" ],
    [ "table", "namespacecom_1_1sun_1_1star_1_1table.html", "namespacecom_1_1sun_1_1star_1_1table" ],
    [ "text", "namespacecom_1_1sun_1_1star_1_1text.html", "namespacecom_1_1sun_1_1star_1_1text" ],
    [ "ucb", "namespacecom_1_1sun_1_1star_1_1ucb.html", "namespacecom_1_1sun_1_1star_1_1ucb" ],
    [ "ui", "namespacecom_1_1sun_1_1star_1_1ui.html", "namespacecom_1_1sun_1_1star_1_1ui" ],
    [ "xforms", "namespacecom_1_1sun_1_1star_1_1xforms.html", "namespacecom_1_1sun_1_1star_1_1xforms" ],
    [ "xsd", "namespacecom_1_1sun_1_1star_1_1xsd.html", "namespacecom_1_1sun_1_1star_1_1xsd" ],
    [ "tiledrendering", "namespacecom_1_1sun_1_1star_1_1tiledrendering.html", "namespacecom_1_1sun_1_1star_1_1tiledrendering" ]
];
